@@ -1,17 +1,22 @@
 // Tool to automatically rebase branches.
 
-use argh::FromArgs;
 use anyhow::Result;
+use argh::FromArgs;
 
-use autorebase::{get_repo_path, autorebase};
+use autorebase::{autorebase, get_repo_path};
 
 #[derive(FromArgs)]
 /// Automatically pull the master branch and rebase all branches without
 /// upstreams onto it.
 struct CliOptions {
     /// the target branch to pull and rebase onto (typically "master" or "develop")
-    #[argh(option, default="String::from(\"master\")")]
+    #[argh(option, default = "String::from(\"master\")")]
     onto: String,
+    /// if there are conflicts, try rebasing commit by commit backwards from the
+    /// target, instead of trying to determind the conflicting commit on the
+    /// target branch directly
+    #[argh(switch)]
+    slow: bool,
 }
 
 fn main() -> Result<()> {
@@ -30,7 +35,7 @@ fn run() -> Result<()> {
     // Find the repo dir in the same way git does.
     let repo_path = get_repo_path()?;
 
-    autorebase(&repo_path, &options.onto)?;
+    autorebase(&repo_path, &options.onto, options.slow)?;
 
     Ok(())
 }
